package version

import (
	"context"
	"testing"

	"github.com/open-io/oio-exporter/common"
	"github.com/open-io/oio-exporter/testutils"
)

func TestVersionModule(t *testing.T) {
	t.Parallel()

	factory := &versionDaemonFactory{
		versions: Versions{
			{Name: "golden_ratio", Type: "command", Command: "echo 1.618"},
		},
	}
	m := common.MakeMetricData()
	params := &versionDaemonParams{
		Namespace: "OPENIO",
		Names: map[string]struct{}{
			"golden_ratio": struct{}{},
		},
	}
	d := factory.New(params)
	ctx := context.TODO()

	if err := d.Init(ctx); err != nil {
		t.Fatalf("Init error: %s", err)
	}

	if err := d.Collect(ctx, m); err != nil {
		t.Fatalf("Collect error: %s", err)
	}

	if err := d.Close(); err != nil {
		t.Fatalf("Close error: %s", err)
	}

	testutils.NewMetricDataTest().
		ForMetric(
			testutils.NewMetricAssertion().
				LabelIs("software", "golden_ratio").
				LabelIs("package", "golden_ratio").
				LabelIs("version", "1.618").
				LabelIs("namespace", "OPENIO").
				NoExtraLabels(),
			"version").
		NoExtraMetrics().
		Check(t, m)
}
